=== modified file 'plugin/js_eval/js_eval.cc'
--- plugin/js_eval/js_eval.cc	2011-09-01 12:18:08 +0000
+++ plugin/js_eval/js_eval.cc	2011-09-02 10:32:57 +0000
@@ -137,15 +137,15 @@
  * @param res Pointer to the drizzled::String object that will contain the result
  * @return a drizzled::String containing the value returned by executed JavaScript code (value of last executed statement) 
  */
-String *JsEvalFunction::val_str(String *str)
+String *JsEvalFunction::val_str( String *str )
 {
-  assert(fixed == 1);
+  assert( fixed == 1 );
   // If we return from any of the error conditions during method, then 
   // return value of the drizzle function is null.
   null_value= true; 
   
   String *source_str=NULL;
-  source_str = args[0]->val_str(str); 
+  source_str = args[0]->val_str( str ); 
   
   // TODO Some of this (ObjectTemplate bindings) should probably be 
   // moved to initialize, but then it must be allocated on the heap.
@@ -164,17 +164,17 @@
   v8::Handle<v8::ObjectTemplate> db = v8::ObjectTemplate::New();
   v8::Handle<v8::ObjectTemplate> js = v8::ObjectTemplate::New();
   // Bind the 'version' function 
-  global->Set(v8::String::New("db"), db);
-  db->Set(v8::String::New("js"), js);
-  js->Set(v8::String::New("version"), v8::FunctionTemplate::New(V8Version));
-  js->Set(v8::String::New("engine"), v8::FunctionTemplate::New(JsEngine));
+  global->Set( v8::String::New("db"), db );
+  db->Set( v8::String::New("js"), js );
+  js->Set( v8::String::New("version"), v8::FunctionTemplate::New(V8Version) );
+  js->Set( v8::String::New("engine"), v8::FunctionTemplate::New(JsEngine) );
   
   // Now bind the arguments into argv[]
   // v8::Array can only be created when context is already entered (otherwise v8 segfaults!)
-  v8::Persistent<v8::Context> context = v8::Context::New(NULL, global);
-  if (context.IsEmpty()) {
+  v8::Persistent<v8::Context> context = v8::Context::New( NULL, global );
+  if ( context.IsEmpty() ) {
     // TODO: how do I set warning/error in the drizzle result?
-    printf("Error in js_eval() while creating JavaScript context in v8.\n");
+    printf( "Error in js_eval() while creating JavaScript context in v8.\n" );
     return NULL;
   }
   context->Enter();
@@ -182,10 +182,39 @@
   v8::Handle<v8::Array> a = v8::Array::New(arg_count-1);
   for( uint64_t n = 1; n < arg_count; n++ )
   {
-    a->Set(n-1, v8::String::New(args[n]->val_str(str)->c_str()));
+    // Need to do this differently for ints, doubles and strings
+    // TODO: There is also ROW_RESULT. Is that relevant here? What does it look like? I could pass rows as an array or object.
+    if( args[n]->result_type() == INT_RESULT ){
+      if( args[n]->is_unsigned() ) {
+        a->Set( n-1, v8::Integer::NewFromUnsigned( (uint32_t) args[n]->val_uint() ) );
+      } else {
+        a->Set( n-1, v8::Integer::New((int32_t)args[n]->val_int() ) );
+      }
+    } else if ( args[n]->result_type() == REAL_RESULT || args[n]->result_type() == DECIMAL_RESULT ) {
+      a->Set( n-1, v8::Number::New(args[n]->val_real() ) );
+    // TODO: Here's a question: Should DECIMAL_RESULT be sent as double or string?
+    // Kind of unusable either way, we'd need to bind some biginteger arithmetic library into the js environment to make them usable
+    } else if ( true || args[n]->result_type() == STRING_RESULT ) {
+      // Default to creating string values in JavaScript
+      a->Set( n-1, v8::String::New(args[n]->val_str(str)->c_str() ) );
+    }
+    // If user has given a name to the arguments, pass these as global variables
+    if( ! args[n]->is_autogenerated_name ) {
+      if( args[n]->result_type() == INT_RESULT ){
+        if( args[n]->is_unsigned() ) {
+          context->Global()->Set( v8::String::New(args[n]->name ), v8::Integer::NewFromUnsigned( (uint32_t) args[n]->val_uint() ) );
+        } else {
+          context->Global()->Set( v8::String::New(args[n]->name ), v8::Integer::New((int32_t)args[n]->val_int() ) );
+        }
+      } else if ( args[n]->result_type() == REAL_RESULT || args[n]->result_type() == DECIMAL_RESULT ) {
+        context->Global()->Set( v8::String::New(args[n]->name ), v8::Number::New(args[n]->val_real() ) );
+      } else if ( true || args[n]->result_type() == STRING_RESULT ) {
+        context->Global()->Set( v8::String::New(args[n]->name ), v8::String::New(args[n]->val_str(str)->c_str() ) );
+      }
+    }
   }
   //Need to fetch the global element back from context, global doesn't work anymore
-  context->Global()->Set(v8::String::New("argv"), a);
+  context->Global()->Set( v8::String::New("arguments"), a );
 
   
   
@@ -196,26 +225,26 @@
   // Convert from drizzled::String to char* string to v8::String.
   v8::Handle<v8::String> source = v8::String::New(source_str->c_str());
   v8::Handle<v8::Script> script = v8::Script::Compile(source);
-  if (script.IsEmpty()) {
+  if ( script.IsEmpty() ) {
     // TODO: how do I set warning/error in the drizzle result?
     // Print errors that happened during compilation.
     ReportException(&try_catch);
     return NULL;
   } else {
     result = script->Run();
-    if (result.IsEmpty()) {
-      assert(try_catch.HasCaught());
+    if ( result.IsEmpty() ) {
+      assert( try_catch.HasCaught() );
       // TODO: how do I set warning/error in the drizzle result?
       // Print errors that happened during execution.
-      ReportException(&try_catch);
+      ReportException( &try_catch );
       // Dispose of Persistent objects before returning. (Is it needed?)
       context->Exit();
       context.Dispose();
       return NULL;
     } else {
-      assert(!try_catch.HasCaught());
-      if (result->IsUndefined()) {
-        printf("js_eval() got Undefined result back from v8.\n");
+      assert( !try_catch.HasCaught() );
+      if ( result->IsUndefined() ) {
+        // Nothing wrong here, but we return Undefined as NULL.
         // Dispose of Persistent objects before returning. (Is it needed?)
         context->Exit();
         context.Dispose();
@@ -231,11 +260,11 @@
   // Convert the result to a drizzled::String and print it.
   // Allocate space to the drizzled::String 
   str->free(); //TODO: Check the source for alloc(), but apparently I don't need this line?
-  str->alloc(rstring->Utf8Length());
+  str->alloc( rstring->Utf8Length() );
   // Now copy string from v8 heap to drizzled heap
-  rstring->WriteUtf8(str->ptr());
+  rstring->WriteUtf8( str->ptr() );
   // drizzled::String doesn't actually set string length properly in alloc(), so set it now
-  str->length(rstring->Utf8Length());
+  str->length( rstring->Utf8Length() );
  
   context->Exit();
   context.Dispose();
@@ -250,10 +279,10 @@
 
 plugin::Create_function<JsEvalFunction> *js_eval_function = NULL;
 
-static int initialize(module::Context &context)
+static int initialize( module::Context &context )
 {
-  js_eval_function = new plugin::Create_function<JsEvalFunction>("js_eval");
-  context.add(js_eval_function);
+  js_eval_function = new plugin::Create_function<JsEvalFunction>( "js_eval" );
+  context.add( js_eval_function );
   // Initialize V8
   v8::V8::Initialize();
   return 0;
@@ -262,12 +291,12 @@
 
 /* v8 related functions ********************************/
 
-v8::Handle<v8::Value> V8Version(const v8::Arguments&) {
-  return v8::String::New(v8::V8::GetVersion());
+v8::Handle<v8::Value> V8Version( const v8::Arguments& ) {
+  return v8::String::New( v8::V8::GetVersion() );
 }
 
-v8::Handle<v8::Value> JsEngine(const v8::Arguments&) {
-  return v8::String::New(JS_ENGINE);
+v8::Handle<v8::Value> JsEngine( const v8::Arguments& ) {
+  return v8::String::New( JS_ENGINE );
 }
 
 

